/*
	File:		UpgraderPluginTypes.r
*/

#ifndef __INSTALLPLUGINTYPES__
#define __INSTALLPLUGINTYPES__

/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Constants
//
/////////////////////////////////////////////////////////////////////////////////////////////////////

#define kSequenceResourceType 			'tsqc'
#define kDataFileFormatRsrcType 		'cfmt'
#define kPluginFormatRsrcType 			'pfmt'
#define kSequenceResourceID				128
#define	kPluginInShell					0
#define kPluginInDefaultFolder 			1

#define kLatestPluginFileFormatVersion 	0,2
#define kLatestDataFileFormatVersion 	0,4

/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Sequence Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////
#define	ShellFlags 														\
		fill bit[16]								/* Reserved */ 
		
type kSequenceResourceType {															
	switch {
		case format2:									
			key integer = 2;					/* Format version */
			ShellFlags;							/* Reserved */
			integer BWSplashPict;				/* 8-bit color splash screen picture - 'PICT' Rsrc ID (optional, enter 0 to ignore) */
			integer ColorSplashPict;			/* B&W splash screen picture - 'PICT' ID */
			integer systemResListID;			/* System file preload list - 'RES#' ID  */

			integer helpPanelResID;				/* Dialog layout of help window (use 1050 as default) - 'DITL' Rsrc ID  */
			integer defaultHelpTitleStrResID;	/* Help window title - 'STR ' Rsrc ID */
			integer defaultHelpTextResID;		/* Default help text - 'TEXT' Rsrc ID */
			integer defaultHelpBasePICTResID;	/* First picture contained in help text - 'PICT' Rsrc ID */

			pstring; 							/* First plug-in name */
			align word;											
			unsigned integer = $$CountOf(pluginList);/* Plug-in List */
			wide array pluginList {
				unsigned longint onlyRunOnce = 1;/* Plug-in flags */
				pstring;						/* Plug-in name */
				align word;											
				pstring;						/* Default next plug-in name */
				align word;											
				unsigned longint;				/* RefCon passed to plug-in */
				unsigned integer;				/* Plug-in file location  - 'flrf' Rsrc ID */
				unsigned integer;				/* Data file preload list - 'RES#' Rsrc ID */
			};
	};
};	

type kDataFileFormatRsrcType {
	byte DataFileMajorRevisionNumber;
	byte DataFileMinorRevisionNumber;
};

type kPluginFormatRsrcType {
	byte PluginMajorRevisionNumber;
	byte PluginMinorRevisionNumber;
};		

/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// File Reference Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////

#define	kUnknownMedia		0		// Net install setup on CD-ROM or hard disk.  Use relative path from Upgrader application.
#define	kFloppyDiskMedia	1		// Multiple floppy disk set.  Use full path starting with floppy volume name.
#define kCDROMDiskMedia 	2		// Multiple CD-ROM disk set.  Use full path starting with CD-ROM volume name.

#define	FileRefFlags 														\
		fill bit[16]										/* Reserved */ 

type 'flrf' {														
	switch {
		case format0:
			key integer = 0;					/* Format version */
			FileRefFlags;						/* Flags, currently unused */
			integer;							/* Original Media Type (kUnknownMedia, kFloppyDiskMedia, or kCDROMDiskMedia) */
			literal longint;					/* File Type */
			literal longint;					/* File Creator */
			longint;							/* File Creation Date (optional) */ 
			pstring;							/* Relative path (media type of kUnknownMedia) or Full Path (media type of kFloppyDiskMedia or kCDROMDiskMedia) */																		\
			align word;
			pstring;							/* File Name */																		\
			align word;
	};
};


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
//  Error list resource The 'ners' resource is a mapping between error numbers and error messages 
//
/////////////////////////////////////////////////////////////////////////////////////////////////////
#define kErrorListRsrcType 'ners'

type kErrorListRsrcType {
	wide array {
		integer;								/* Internal error number */
		integer;								/* Index in STR# ID=500 resource */
		integer;								/* Dialog to display - 'DLOG' Rsrc ID */
		};
	};
	

/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Resource List Resource   (Used for preloading necessary resources when running off ejectable media)
//
/////////////////////////////////////////////////////////////////////////////////////////////////////


type 'RES#' {
	integer = $$CountOf(ResArray);
	array ResArray {
		literal longint;						/* Resource type to preload */
		integer;								/* Resource ID to preload*/
	};
};


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Environment Filter (Incompatible Hardware) Plug-in Preference Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////

#define	EFPPrefFormatThreeFlags 														\
		boolean		kMachineListNotSupported, kMachinListSupported;		/* Whether machine list is exclusive or inclusive */				\
		boolean		kDontUseCodeRsrc, kUseCodeRsrc;						/* Whether the specified code resource should be run */ \
		boolean		kDontRunCodeRsrcExclusively, kRunCodeRsrcExclusively; /* Whether only the code resource should be run, or if the code resource should be run in addition to the other tests */ \
		fill bit[13]										/* Reserved */ 

type 'efpr' {														
	switch {
		case format3:
			key integer = 3;					/* Format version */
			EFPPrefFormatThreeFlags;			/* Flags */
			integer;							/* Minimum release SSW version */
			integer;							/* ID of 'STR#' resource that contains names of computers */
			literal longint;					/* Resource type of code resource */
			integer;							/* Resource ID of code resource */
			integer = $$CountOf(MachIDArray);	/* number of items in machine ID list */
			array MachIDArray {
				integer;						/* Machine gestalt ID */
			};
	};
};


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Welcome Plug-in Preference Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////

#define	WPPrefFlags 														\
		boolean		kReserved1, kReserved2;																													\
		boolean		kHelpTextInRsrc, kHelpTextInFile;		/* Whether help text is in 'TEXT' resource in data file or in a separate SimpleText file */				\
		fill bit[14]										/* Reserved */ 

type 'wppr' {														
	switch {
		case format2:							/* <17>				*/
			key integer = 2;					/* Format version */
			WPPrefFlags;						/* Preference Flags */
			integer;							/* Main Text (location depends on flags) - 'flrf' or 'TEXT' Rsrc ID */
			integer;							/* Help text (location depends on flags) - 'flrf' or 'TEXT' Rsrc ID */
			integer;							/* First help text picture (when using kMainTextInRsrc flag) - 'PICT' Rsrc ID */
			integer;							/* Background color panel (B&W:  ID + 1) - 'PICT' Rsrc ID */
			integer;							/* Plug-in string list Rsrc ID (STR#) - 'STR#' Rsrc ID */
			
	};
};


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Target Selection Plug-in Preference Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////

#define	TSPPrefFlags 															\
		boolean		kHelpTextInRsrc, kHelpTextInFile;						/* Whether help text is in 'TEXT' resource in data file or in a separate SimpleText file */		\
		boolean		kDontCheckSystemVersion, kCheckSystemVersion;			/* Do we check if the system software is already installed or not */	\
		boolean		kDontShowCleanInstall, kShowCleanInstall;				/* Whether a clean installation is allowed.  Should only be turned if full System installation is supported. */				\
		boolean		kDontRequireTargetSysVersion, kRequireTargetSysVersion;	/* Allows the Select button to be dimmed if the target system version isn't within the range. */				\
		boolean		kDefaultDirtyInstall, kDefaultCleanInstall;				/* Defaultly performs a clean install */		\
		fill bit[11]														/* Reserved */ 

type 'tspr' {														
	switch {
		case format4:
			key integer = 4;					/* Format version */
			TSPPrefFlags;						/* Preference Flags */
			longint;							/* Actual Kbytes copied for recommended installation */
			integer;							/* System software to check against if kCheckSystemVersion is set in the flag field	 */
			integer;							/* Lowest System software version required if kRequireTargetSysVersion is set in the flag field	 */
			integer;							/* Highest System software version required if kRequireTargetSysVersion is set in the flag field	 */
			integer;							/* If system version matches, the plug-in name to branch to for a reinstall or clean installation - STR  Rsrc ID */
			integer;							/* If system version matches, the plug-in name to branch to for a add/remove installation - STR  Rsrc ID */
			integer;							/* Help text (location depends on flags) - 'flrf' or 'TEXT' Rsrc ID */
			integer;							/* First help text picture (when using kMainTextInRsrc flag) - 'PICT' Rsrc ID */
			integer;							/* Plug-in string list - 'STR#' Rsrc ID */
			longint;							/* Number of file forks created during installation. */

	};
};


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Read Me Plug-in Preference Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////

#define	RMPPrefFlags 						\
		boolean		kMainTextInRsrc, kMainTextInFile;		/* Whether text is in 'TEXT' resource in data file or in a separate SimpleText file */				\
		boolean		kHelpTextInRsrc, kHelpTextInFile;		/* Whether text is in 'TEXT' resource in data file or in a separate SimpleText file */				\
		fill bit[14]										/* Reserved */ 

type 'rmpr' {														
	switch {
		case format1:
			key integer = 1;					/* Format version */
			RMPPrefFlags;						/* Preference Flags */
			integer;							/* Main Text (location depends on flags) - 'flrf' or 'TEXT' Rsrc ID */
			integer;							/* First main text picture (when using kMainTextInRsrc flag) - 'PICT' Rsrc ID */
			integer;							/* Help text (location depends on flags) - 'flrf' or 'TEXT' Rsrc ID */
			integer;							/* First help text picture (when using kHelpTextInRsrc flag) - 'PICT' Rsrc ID */
			integer;							/* Plug-in string list Rsrc ID (STR#) - 'STR#' Rsrc ID */
	};
};

/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// License Viewer Plug-in Preference Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////

#define	LVPPrefFlags 						\
		boolean		kHelpTextInRsrc, kHelpTextInFile;		/* Whether help text is in 'TEXT' resource in data file or in a separate SimpleText file */				\
		fill bit[15]								/* Reserved */ 


#define	LangEntryFlags 						\
		boolean		kOneByte, kTwoByte;			/* Whether language is one byte-base or two */		\
		boolean		kTextInRsrc, kTextInFile;	/* Whether text is in 'TEXT' resource in data file or in a separate SimpleText file */				\
		fill bit[14]							/* Reserved */ 
		
type 'swpr' {														
	switch {
		case format4:
			key integer = 4;					/* Format version */
			LVPPrefFlags;						/* Preference flags */
			integer;							/* Help text (location depends on flags) - 'flrf' or 'TEXT' Rsrc ID */
			integer;							/* First help text picture (when using kMainTextInRsrc flag) - 'PICT' Rsrc ID */
			integer;							/* Plug-in string list - 'STR#' Rsrc ID */
			integer;							/* Disagree plug-in name string - 'STR ' Rsrc ID */
			integer;							/* Panel title string list - STR# Rsrc ID */
			integer;							/* Pop-up menu string list - 'STR#' Rsrc ID */
			integer;							/* Continue button string list - 'STR#' Rsrc ID */
			integer;							/* Save button string list - 'STR#' Rsrc ID */
			integer;							/* Print button string list - 'STR#' Rsrc ID */
			integer;							/* Go Back button string list - 'STR#' Rsrc ID 	*/
			integer;							/* Agree button string list - 'STR#' Rsrc ID */
			integer;							/* Disagree button string list - 'STR#' Rsrc ID */
			integer;							/* Agree/Disagree dialog text string list - 'STR#' Rsrc ID */

			integer;							/* Default language ID */
			integer = $$CountOf (LanguageArray);/* Number of languages */
			array LanguageArray
				{
				LangEntryFlags;					/* Language flags */
				integer;						/* System Language ID (from Script.h) */
				integer;						/* License text (location depends on flags) - 'flrf' or 'TEXT' Rsrc ID */
				integer;						/* First license text picture (when using kMainTextInRsrc flag) - 'PICT' Rsrc ID */
				};
				
	};

};


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Installation Plug-in Preference Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////


#define	IPPrefFlags 														\
		boolean		kDontRunCleanupApp, kRunCleanupApp;						/* Whether the clean up application should be run after installation */				\
		boolean		kDontAllowEasyUpgradeMode, kAllowEasyUpgradeMode;		/* Is Easy Upgrade mode available? */			\
		boolean		kDontAllowCustomUpgradeMode, kAllowCustomUpgradeMode;	/* Is Custom Upgrade mode available? */			\
		boolean		kHelpTextInRsrc, kHelpTextInFile;						/* Whether help text is in 'TEXT' resource in data file or in a separate SimpleText file */				\
		boolean		kDontUpdateDrivers, kUpdateDrivers;						/* Whether updating drivers should performed */				\
		boolean		kDontCheckDisk, kCheckDisk;								/* Whether target disk should be checked before installation */				\
		boolean		kDontAllowUserToTurnOffCheckDisk, kAllowUserToTurnOffCheckDisk;	/* Whether the Check Disk checkbox shows in the Options dialog */				\
		boolean		kDontRequireSelectionSetFile, kRequireSelectionSetFile;	/* Whether a selection set file is required in order to install. */				\
		boolean		kDontAllowReports, kAllowReports;						/* Whether the option to create an installation report is shown in Options dialog. */				\
		boolean		kDontInitiallySelectReporting, kInitiallySelectReporting;/* Whether reporting is initially selected or not. */				\
		fill bit[6]															/* Reserved */ 

#define	TaskFlags 																						\
		boolean		kOptionalSubTask, kRequiredSubTask;		/* Optional or required software item  */	\
		boolean		kDontSelectInitially, kSelectInitially;	/* Initially selected software item */					\
		boolean		kStandAloneInstallerScript, kForceInstallWithPriorInstallerScript;	/* Parasite of previous item */	\
		boolean		kReserved1, kReserved2;		\
		boolean		kNoEasyInstallModeAvailable, kEasyInstallModeAvailable;	/* Installer script supports easy install */	\
		boolean		kNoCustomInstallModeAvailable, kCustomInstallModeAvailable;		/* Installer script supports custom install */	\
		boolean		kNoCustomRemoveModeAvailable, kCustomRemoveModeAvailable;		/* Installer script supports custom remove */	\
		boolean		kDontShowFeatureSetsInCustomList, kShowFeatureSetsInCustomList;		/* Features sets can be shown in the the custom install selection window */	\
		boolean		kDontUseCompFeatureLookup, kUseCompFeatureLookup;		/* Helps certain types of rule frameworks be more compatibile with custom selection. */	\
		boolean		kDontRequireRestartForEasy, kRequireRestartForEasy;		/* Whether the Installer requires a restart when installing an easy feature set onto the boot volume. */	\
		fill bit[6]											/* Reserved */ 

type 'ippr' {														
	switch {
		case format3:
			key integer = 3;					/* Format version */
			IPPrefFlags;						/* Installer Module Preference Flags */
			longint;							/* Revision Number, set by ModifierTool and used to match a Selection Set file to a data file. */
			integer;							/* General Strings STR# Rsrc ID */
			integer;							/* Name of target selection plug-in 'STR ' Rsrc ID */
			integer;							/* Software item names list - STR# Rsrc ID */
			integer;							/* DFA application - 'flrf' Rsrc ID*/
			integer;							/* Drive Setup application - 'flrf' Rsrc ID */
			integer;							/* Cleanup application - 'flrf' Rsrc ID */
			integer;							/* Cleanup application document - 'flrf' Rsrc ID */
			integer;							/* Help text (location depends on flags) - 'flrf' or 'TEXT' Rsrc ID */
			integer;							/* First help text picture (when text in 'TEXT' rsrc) - 'PICT' Rsrc ID */
			integer;							/* Default color billboard picture - 'PICT' Rsrc ID */
			integer;							/* Default BW billboard picture - 'PICT' Rsrc ID */
 			integer;							/* Easy Mode Text - 'TEXT' Rsrc ID */
			integer;							/* Background color panel - 'PICT' Rsrc ID */
			integer;							/* Background BW panel - 'PICT' Rsrc ID */
			longint;							/* Text Encoding value (replaced by new pref. rsrc in Installer scripts.) */
			integer = $$CountOf ( RemapIDPairs );	/* Number of ID Pairs */
			wide array RemapIDPairs{
				integer;						/* Unsupported machine ID */
				integer;						/* Supported machine ID */
			};
			integer = $$CountOf ( Tasks );		/* Number of software items */
			wide array Tasks{
				TaskFlags;						/* Flags */
				integer;						/* Software installer application - 'flrf' Rsrc ID */
				integer;						/* Software installer application document - 'flrf' Rsrc ID */
				integer;						/* Software installer application document for PPC machines only - 'flrf' Rsrc ID  */
				literal longint;				/* Preflight code resource type (optional) */
				integer;						/* Preflight code resource ID (optional) - 'pffn' Rsrc ID */
				longint;						/* RefCon passed to preflight code resource */
				integer;						/* Billboard Rsrc ID (optional) - 'pdgs' Rsrc ID */
				longint;						/* Actual Kbytes copied Easy Install */
				longint;						/* Number of file forks for Easy Install */
				integer;						/* Multiplier for speed of subtask in relation to Installer Engine - percentage */
				integer;						/* Component Info - 'TEXT' Rsrc ID  */
				integer = $$CountOf ( HostFeatureIDs );/* Number of host feature IDs (use for parasites only) */
				wide array HostFeatureIDs{
					integer;						/* Host Feature ID */
				};
			};
	};
};


// Billboard resource

 #define	billboardPictureFlags							\
	boolean		kDoNotLoop, kLoop;							\
	boolean		kStopOnLast, kStopOnDefault;				\
		fill bit[14]	

type 'pdgs' {
	switch {
		case format0:
			key integer = 0;			/* Format version */
			
			switch {
				case simplePictureDisplay:
					key literal longint = 'PICT';	/* Picture billboard type */
					billboardPictureFlags;			/* Flags */
					integer = $$CountOf (pictureList);	/* Number of records */
					wide array pictureList  {
						integer;		/* Minimum seconds to display */
						integer;		/* Default color billboard picture - PICT ID */
						integer;		/* Default B&W billboard picture - PICT ID */
						integer;		/* Optional File Ref. - flrf ID */
				};
		};
	};
};


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Conclusions Plug-in Preference Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////

#define	CCPPrefFlags 						\
		boolean		kDefaultMessage, kCustomMessageProvide;		/* Use kCustomMessageProvide when providing a customized message in the data file */	\
		fill bit[15]							/* Reserved 									*/ 

type 'ccpr' {														
	switch {
		case format1:
			key integer = 1;					/* Format version 								*/
			CCPPrefFlags;						/* Preference Flags 							*/
			integer;							/* Plug-in name to branch to after continuing - 'STR ' Rsrc ID */
			integer;							/* Plug-in string list - 'STR#' Rsrc ID */
	};

};


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Auto Start Resource
//
/////////////////////////////////////////////////////////////////////////////////////////////////////

#define	AutoInstallFlags 						\
		boolean		kDontStartAutoInstall, kStartAutoInstall;		/* Use kStartAutoInstall to cause the Installation Plug-in to automatcially start installation */	\
		fill bit[15]							/* Reserved 									*/ 

type 'auin' {														
	switch {
		case format0:
			key integer = 0;					/* Format version */
			AutoInstallFlags;					/* Flags */
	};

};



#endif
